@@ -1,7 +1,7 @@
-/* BLDCFG.C     (c) Copyright Roger Bowler, 1999-2005                */
+/* BLDCFG.C     (c) Copyright Roger Bowler, 1999-2006                */
 /*              ESA/390 Configuration Builder                        */
 
-/* Interpretive Execution - (c) Copyright Jan Jaeger, 1999-2005      */
+/* Interpretive Execution - (c) Copyright Jan Jaeger, 1999-2006      */
 
 /*-------------------------------------------------------------------*/
 /* This module builds the configuration tables for the Hercules      */
@@ -20,7 +20,7 @@
 /*      PANRATE parameter by Reed H. Petty                           */
 /*      CPUPRIO parameter by Jan Jaeger                              */
 /*      HERCPRIO, TODPRIO, DEVPRIO parameters by Mark L. Gaubatz     */
-/* z/Architecture support - (c) Copyright Jan Jaeger, 1999-2005      */
+/* z/Architecture support - (c) Copyright Jan Jaeger, 1999-2006      */
 /*-------------------------------------------------------------------*/
 
 #include "hstdinc.h"
@@ -507,6 +507,31 @@ static size_t parse_devnums(const char *spec,DEVARRAY **da)
     return(gcount);
 }
 
+
+static inline S64 lyear_adjust(int epoch)
+{
+int year, leapyear;
+U64 tod = hw_clock();
+
+    if(tod >= TOD_YEAR)
+    {
+        tod -= TOD_YEAR;
+        year = (tod / TOD_4YEARS * 4) + 1;
+        tod %= TOD_4YEARS;
+        if((leapyear = tod / TOD_YEAR) == 4)
+            year--;
+        year += leapyear;
+    }
+    else
+       year = 0;
+
+    if(epoch > 0)
+        return (((year % 4) != 0) && (((year % 4) - (epoch % 4)) <= 0)) ? -TOD_DAY : 0;
+    else
+        return (((year % 4) == 0 && (-epoch % 4) != 0) || ((year % 4) + (-epoch % 4) > 4)) ? TOD_DAY : 0;
+}
+
+
 DLL_EXPORT char *config_cnslport = "3270";
 /*-------------------------------------------------------------------*/
 /* Function to build system configuration                            */
@@ -528,6 +553,7 @@ char   *snumvec;                        /* -> Number of VFs          */
 char   *sarchmode;                      /* -> Architectural mode     */
 char   *sloadparm;                      /* -> IPL load parameter     */
 char   *ssysepoch;                      /* -> System epoch           */
+char   *syroffset;                      /* -> System year offset     */
 char   *stzoffset;                      /* -> System timezone offset */
 char   *sdiag8cmd;                      /* -> Allow diagnose 8       */
 char   *sshcmdopt;                      /* -> SHCMDOPT shell cmd opt */
@@ -579,6 +605,8 @@ U16     shrdport;                       /* Shared device port number */
 int     archmode;                       /* Architectural mode        */
 S32     sysepoch;                       /* System epoch year         */
 S32     tzoffset;                       /* System timezone offset    */
+S32     yroffset;                       /* System year offset        */
+S64     ly1960;                         /* Leap offset for 1960 epoch*/
 int     diag8cmd;                       /* Allow diagnose 8 commands */
 BYTE    shcmdopt;                       /* Shell cmd allow option(s) */
 double  toddrag;                        /* TOD clock drag factor     */
@@ -627,7 +655,7 @@ int     dummyfd[OPTION_SELECT_KLUDGE];  /* Dummy file descriptors --
 char **newargv;
 char **orig_newargv;
 #endif
-BYTE    pathname[MAX_PATH];             /* file path in host format  */
+char    pathname[MAX_PATH];             /* file path in host format  */
 
 #if !defined(OPTION_CONFIG_SYMBOLS)
     UNREFERENCED(j);
@@ -660,6 +688,7 @@ BYTE    pathname[MAX_PATH];             /* file path in host format  */
     numcpu = 0;
     numvec = MAX_CPU_ENGINES;
     sysepoch = 1900;
+    yroffset = 0;
     tzoffset = 0;
     diag8cmd = 0;
     shcmdopt = 0;
@@ -749,6 +778,7 @@ BYTE    pathname[MAX_PATH];             /* file path in host format  */
         sarchmode = NULL;
         sloadparm = NULL;
         ssysepoch = NULL;
+        syroffset = NULL;
         stzoffset = NULL;
         sdiag8cmd = NULL;
         sshcmdopt = NULL;
@@ -855,6 +885,15 @@ BYTE    pathname[MAX_PATH];             /* file path in host format  */
             else if (strcasecmp (keyword, "sysepoch") == 0)
             {
                 ssysepoch = operand;
+                if (addargc > 0)
+                {
+                    syroffset = addargv[0];
+                    addargc--;
+                }
+            }
+            else if (strcasecmp (keyword, "yroffset") == 0)
+            {
+                syroffset = operand;
             }
             else if (strcasecmp (keyword, "tzoffset") == 0)
             {
@@ -1369,16 +1408,31 @@ BYTE    pathname[MAX_PATH];             /* file path in host format  */
         if (ssysepoch != NULL)
         {
             if (strlen(ssysepoch) != 4
-                || sscanf(ssysepoch, "%d%c", &sysepoch, &c) != 1)
+                || sscanf(ssysepoch, "%d%c", &sysepoch, &c) != 1
+                || sysepoch <= 1800 || sysepoch >= 2100)
             {
                 fprintf(stderr, _("HHCCF022S Error in %s line %d: "
                         "%s is not a valid system epoch.\n"
-                        "Patch config.c to expand the table\n"),
+                        "          The only valid values are "
+                        "1801-2099\n"),
                         fname, stmt, ssysepoch);
                 delayed_exit(1);
             }
         }
 
+        /* Parse year offset operand */
+        if (syroffset != NULL)
+        {
+            if (sscanf(syroffset, "%d%c", &yroffset, &c) != 1
+                || (yroffset < -142) || (yroffset > 142))
+            {
+                fprintf(stderr, _("HHCCF070S Error in %s line %d: "
+                        "%s is not a valid year offset\n"),
+                        fname, stmt, syroffset);
+                delayed_exit(1);
+            }
+        }
+
         /* Parse timezone offset operand */
         if (stzoffset != NULL)
         {
@@ -1830,13 +1884,62 @@ BYTE    pathname[MAX_PATH];             /* file path in host format  */
     csr_reset();
 
     /* Set up the system TOD clock offset: compute the number of
-     * microseconds offset to the year 1900 */
+     * microseconds offset to 0000 GMT, 1 January 1900 */
 
-    sysepoch -= 1900;
-    set_tod_epoch((sysepoch*365+((sysepoch>0?sysepoch-1:sysepoch)/4))*-1382400000000LL);
+#if 0
+    if (sysepoch == 1928)
+    {
+        sysepoch = 1900;
+        yroffset = -28;
+        logmsg( _("HHCCF071W SYSEPOCH 1928 is deprecated and "
+              	"will be invalid in a future release.\n"
+                "          Specify SYSEPOCH 1900 and YROFFSET -28 instead.\n"));
+    }
+    if (sysepoch == 1988)
+    {
+        sysepoch = 1960;
+        yroffset = -28;
+        logmsg( _("HHCCF071W SYSEPOCH 1988 is deprecated and "
+              	"will be invalid in a future release.\n"
+                "          Specify SYSEPOCH 1960 and YROFFSET -28 instead.\n"));
+    }
+    /* Only 1900 and 1960 are valid by this point. There are 16*1000000 clock
+       increments in one second, 86400 seconds in one day, and 14 leap days
+       between 1 January 1900 and 1 January 1960. */
+    if (sysepoch == 1960)
+        set_tod_epoch(((60*365)+14)*-TOD_DAY);
+    else
+        set_tod_epoch(0);
+
+    /* Set the year offset. This has been handled above for the case of
+       SYSEPOCH 1928 or 1988, for backwards compatibility. */
+    adjust_tod_epoch((yroffset*365+(yroffset/4))*TOD_DAY);
+#else
+    if(sysepoch != 1900 && sysepoch != 1960)
+    {
+        if(sysepoch < 1960)
+            logmsg(_("HHCCF072W SYSEPOCH %04d is deprecated. "
+                     "Please specify \"SYSEPOCH 1900 %s%d\".\n"),
+                     sysepoch, 1900-sysepoch > 0 ? "+" : "", 1900-sysepoch);
+        else
+            logmsg(_("HHCCF073W SYSEPOCH %04d is deprecated. "
+                     "Please specify \"SYSEPOCH 1960 %s%d\".\n"),
+                     sysepoch, 1960-sysepoch > 0 ? "+" : "", 1960-sysepoch);
+    }
+
+    if(sysepoch == 1960 || sysepoch == 1988)
+        ly1960 = TOD_DAY;
+    else
+        ly1960 = 0;
+
+    sysepoch -= 1900 + yroffset;
+
+    set_tod_epoch(((sysepoch*365+(sysepoch/4))*-TOD_DAY)+lyear_adjust(sysepoch)+ly1960);
+#endif
+    sysblk.sysepoch = sysepoch;
 
     /* Set the timezone offset */
-    ajust_tod_epoch((tzoffset/100*3600+(tzoffset%100)*60)*16000000LL);
+    adjust_tod_epoch((tzoffset/100*3600+(tzoffset%100)*60)*16000000LL);
 
     /* Set clock steering based on drag factor */
     set_tod_steering(-(1.0-(1.0/toddrag)));
@@ -1996,6 +2099,7 @@ BYTE    pathname[MAX_PATH];             /* file path in host format  */
      * (sysblk.pcpu) is not configured (ie cpu_thread not started).
      */
     sysblk.dummyregs.mainstor = sysblk.mainstor;
+    sysblk.dummyregs.psa = (PSA*)sysblk.mainstor;
     sysblk.dummyregs.storkeys = sysblk.storkeys;
     sysblk.dummyregs.mainlim = sysblk.mainsize - 1;
     sysblk.dummyregs.dummy = 1;
@@ -2037,7 +2141,7 @@ BYTE    pathname[MAX_PATH];             /* file path in host format  */
         ,( sysblk.asnandlxreuse ) ? "EN" : "DIS"
         ,( sysblk.diag8cmd      ) ? "EN" : "DIS"
     );
-
+    
     /* Start the CPUs */
     obtain_lock (&sysblk.intlock);
     for(i = 0; i < numcpu; i++)
