@@ -1,8 +1,8 @@
-/* CPU.C        (c) Copyright Roger Bowler, 1994-2005                */
+/* CPU.C        (c) Copyright Roger Bowler, 1994-2006                */
 /*              ESA/390 CPU Emulator                                 */
 
-/* Interpretive Execution - (c) Copyright Jan Jaeger, 1999-2005      */
-/* z/Architecture support - (c) Copyright Jan Jaeger, 1999-2005      */
+/* Interpretive Execution - (c) Copyright Jan Jaeger, 1999-2006      */
+/* z/Architecture support - (c) Copyright Jan Jaeger, 1999-2006      */
 
 /*-------------------------------------------------------------------*/
 /* This module implements the CPU instruction execution function of  */
@@ -398,20 +398,6 @@ static char *pgmintname[] = {
         RELEASE_MAINLOCK(realregs->guestregs);
 #endif /*defined(FEATURE_INTERPRETIVE_EXECUTION)*/
 
-    /* Unlock the TOD lock if held */
-    if (realregs->todlock)
-    {
-        realregs->todlock = 0;
-        release_lock(&sysblk.todlock);
-    }
-#if defined(FEATURE_INTERPRETIVE_EXECUTION)
-    if(realregs->sie_active && realregs->guestregs->todlock)
-    {
-        realregs->guestregs->todlock = 0;
-        release_lock(&sysblk.todlock);
-    }
-#endif /*defined(FEATURE_INTERPRETIVE_EXECUTION)*/
-
     /* Remove PER indication from program interrupt code
        such that interrupt code specific tests may be done.
        The PER indication will be stored in the PER handling
@@ -1108,7 +1094,7 @@ int   cpu  = *ptr;
     if (!sysblk.todtid)
     {
         if ( create_thread (&sysblk.todtid, &sysblk.detattr,
-             timer_update_thread, NULL) )
+             timer_update_thread, NULL, "timer_update_thread") )
         {
             logmsg (_("HHCCP006S Cannot create timer thread: %s\n"),
                            strerror(errno));
@@ -1161,11 +1147,19 @@ int i;
     regs->arch_mode = sysblk.arch_mode;
     regs->chanset = cpu;
     regs->mainstor = sysblk.mainstor;
+    /* 
+     * ISW20060125 : LINE REMOVED : This is the job of 
+     *               the INITIAL CPU RESET
+     */
+#if 0
+    regs->psa = (PSA*)regs->mainstor;
+#endif
     regs->storkeys = sysblk.storkeys;
     regs->mainlim = sysblk.mainsize - 1;
     regs->tod_epoch = get_tod_epoch();
 
     initialize_condition (&regs->intcond);
+    regs->cpulock = &sysblk.cpulock[cpu];
 
 #if defined(_FEATURE_VECTOR_FACILITY)
     regs->vf = &sysblk.vf[cpu];
@@ -1269,11 +1263,11 @@ void ARCH_DEP(process_interrupt)(REGS *regs)
     regs->tracing = (sysblk.instbreak || sysblk.inststep || sysblk.insttrace);
 
     /* Perform invalidation */
-    if (regs->invalidate)
+    if (unlikely(regs->invalidate))
         ARCH_DEP(invalidate_tlbe)(regs, regs->invalidate_main);
 
     /* Take interrupts if CPU is not stopped */
-    if (regs->cpustate == CPUSTATE_STARTED)
+    if (likely(regs->cpustate == CPUSTATE_STARTED))
     {
         /* Process machine check interrupt */
         if ( OPEN_IC_MCKPENDING(regs) )
@@ -1306,7 +1300,7 @@ void ARCH_DEP(process_interrupt)(REGS *regs)
     } /*CPU_STARTED*/
 
     /* If CPU is stopping, change status to stopped */
-    if (regs->cpustate == CPUSTATE_STOPPING)
+    if (unlikely(regs->cpustate == CPUSTATE_STOPPING))
     {
         /* Change CPU status to stopped */
         regs->opinterv = 0;
@@ -1365,8 +1359,9 @@ void ARCH_DEP(process_interrupt)(REGS *regs)
     } /* end if(restart) */
 
     /* This is where a stopped CPU will wait */
-    if (regs->cpustate == CPUSTATE_STOPPED)
+    if (unlikely(regs->cpustate == CPUSTATE_STOPPED))
     {
+    S64 saved_timer;
 #ifdef OPTION_MIPS_COUNTING
         regs->waittod = hw_clock();
 #endif
@@ -1374,6 +1369,12 @@ void ARCH_DEP(process_interrupt)(REGS *regs)
         /* Wait until there is work to do */
         HDC1(debug_cpu_state, regs);
 
+        /* The CPU timer is not being decremented for
+         * a CPU that is in the manual state
+         * (e.g. stopped in single step mode
+         * or otherwise)
+         */
+        saved_timer = cpu_timer(regs);
         regs->ints_state = IC_INITIAL_STATE;
         sysblk.started_mask &= ~BIT(regs->cpuad);
         while (regs->cpustate == CPUSTATE_STOPPED)
@@ -1382,6 +1383,7 @@ void ARCH_DEP(process_interrupt)(REGS *regs)
         }
         sysblk.started_mask |= BIT(regs->cpuad);
         regs->ints_state |= sysblk.ints_state;
+        set_cpu_timer(regs,saved_timer);
 
         HDC1(debug_cpu_state, regs);
 
@@ -1475,6 +1477,7 @@ int     shouldbreak;                    /* 1=Stop at breakpoint      */
         ARCH_DEP(display_inst) (regs, regs->ip);
         if (sysblk.inststep || shouldbreak)
         {
+        S64 saved_timer;
             /* Put CPU into stopped state */
             regs->opinterv = 0;
             regs->cpustate = CPUSTATE_STOPPED;
@@ -1484,12 +1487,19 @@ int     shouldbreak;                    /* 1=Stop at breakpoint      */
 
             HDC1(debug_cpu_state, regs);
 
+            /* The CPU timer is not being decremented for
+             * a CPU that is in the manual state
+             * (e.g. stopped in single step mode
+             * or otherwise)
+             */
+            saved_timer = cpu_timer(regs);
             sysblk.waiting_mask |= BIT(regs->cpuad);
             while (regs->cpustate == CPUSTATE_STOPPED)
             {
                 wait_condition (&regs->intcond, &sysblk.intlock);
             }
             sysblk.waiting_mask &= ~BIT(regs->cpuad);
+            set_cpu_timer(regs, saved_timer);
 
             HDC1(debug_cpu_state, regs);
 
