@@ -1,5 +1,5 @@
-/* Code borrowed from dasdpdsu Copyright 1999-2005 Roger Bowler      */
-/* Changes and additions Copyright 2001-2005, James M. Morrison      */
+/* Code borrowed from dasdpdsu Copyright 1999-2006 Roger Bowler      */
+/* Changes and additions Copyright 2001-2006, James M. Morrison      */
 
 /*-------------------------------------------------------------------*/
 /*                                                                   */
@@ -1091,10 +1091,10 @@ int main(int argc, char **argv) {
     FILE    *fout = NULL;           // output file
     CIFBLK  *cif;
     int      dsn_recs_written = 0, bail, dsorg, rc;
-    BYTE     pathname[MAX_PATH];
+    char     pathname[MAX_PATH];
 
-    fprintf(stderr, "dasdseq %s Copyright 1999-2005 Roger Bowler\n"
-        "Portions Copyright 2001-2005 James M. Morrison\n", VERSION);
+    fprintf(stderr, "dasdseq %s Copyright 1999-2006 Roger Bowler\n"
+        "Portions Copyright 2001-2006 James M. Morrison\n", VERSION);
     if (debug) fprintf(stderr, "DEBUG enabled\n");
 
 //  Parse command line
