@@ -1,4 +1,4 @@
-/* DASDTAB.C    (c) Copyright Roger Bowler, 1999-2005                */
+/* DASDTAB.C    (c) Copyright Roger Bowler, 1999-2006                */
 /*              Hercules Supported DASD definitions                  */
 
 /*-------------------------------------------------------------------*/
@@ -24,6 +24,10 @@
 /*-------------------------------------------------------------------*/
 static CKDDEV ckdtab[] = {
 /* name         type model clas code prime a hd    r0    r1 har0   len sec    rps  f f1  f2   f3   f4 f5 f6  cu */
+ {"2305",      0x2305,0x00,0x20,0x00,   48,0, 8,14568,14136, 432,14568, 90,0x0000,-1,202,432,  0,   0,  0,0,"2835"},
+ {"2305-1",    0x2305,0x00,0x20,0x00,   48,0, 8,14568,14136, 432,14568, 90,0x0000,-1,202,432,  0,   0,  0,0,"2835"},
+ {"2305-2",    0x2305,0x02,0x20,0x00,   96,0, 8,14858,14660, 198,14858, 90,0x0000,-1, 91,198,  0,   0,  0,0,"2835"},
+
  {"2311",      0x2311,0x00,0x20,0x00,  200,3,10,    0, 3625,   0, 3625,  0,0x0000,-2,20, 61, 537, 512,  0,0,"2841"},
  {"2311-1",    0x2311,0x00,0x20,0x00,  200,3,10,    0, 3625,   0, 3625,  0,0x0000,-2,20, 61, 537, 512,  0,0,"2841"},
 
@@ -81,6 +85,7 @@ static CKDDEV ckdtab[] = {
 /*-------------------------------------------------------------------*/
 static CKDCU ckdcutab[] = {
 /* name          type model code features   ciws -------- */
+ {"2835",       0x2835,0x00,0x00,0x50000103,0,0,0,0,0,0,0,0},
  {"2841",       0x2841,0x00,0x00,0x50000103,0,0,0,0,0,0,0,0},
  {"3830",       0x3830,0x02,0x00,0x50000103,0,0,0,0,0,0,0,0},
  {"3880",       0x3880,0x05,0x09,0x80000000,0,0,0,0,0,0,0,0},
