@@ -1,7 +1,7 @@
 ////////////////////////////////////////////////////////////////////////////////////
 //         fthreads.c           Fish's WIN32 version of pthreads
 ////////////////////////////////////////////////////////////////////////////////////
-// (c) Copyright "Fish" (David B. Trout), 2001-2005. Released under the Q Public License
+// (c) Copyright "Fish" (David B. Trout), 2001-2006. Released under the Q Public License
 // (http://www.conmicro.cx/hercules/herclic.html) as modifications to Hercules.
 ////////////////////////////////////////////////////////////////////////////////////
 
@@ -920,7 +920,8 @@ int  fthread_create
     fthread_t*       pdwThreadID,
     fthread_attr_t*  pThreadAttr,
     PFT_THREAD_FUNC  pfnThreadFunc,
-    void*            pvThreadArgs
+    void*            pvThreadArgs,
+    char*            pszName
 )
 {
     static BOOL            bDidInit = FALSE;
@@ -1023,6 +1024,8 @@ int  fthread_create
 
     InsertListHead ( &ThreadListHead, &pFTHREAD->ThreadListLink );
 
+    SET_THREAD_NAME_ID ( dwThreadID, pszName );
+
     UnlockThreadsList();
 
     return RC(0);
