@@ -1,7 +1,7 @@
 /*
 || ----------------------------------------------------------------------------
 ||
-|| HETGET.C     (c) Copyright Leland Lucius, 2000-2005
+|| HETGET.C     (c) Copyright Leland Lucius, 2000-2006
 ||              Released under terms of the Q Public License.
 ||
 || Extract files from an HET file
@@ -776,7 +776,7 @@ main( int argc, char *argv[] )
             /*
             || Open the output file
             */
-            BYTE pathname[MAX_PATH];
+            char pathname[MAX_PATH];
             hostpath(pathname, opts.ofile, sizeof(pathname));
             outf = fopen( pathname, "wb" );
             if( outf != NULL )
