@@ -199,6 +199,33 @@
 #define HOW_TO_IMPLEMENT_SH_COMMAND       USE_ANSI_SYSTEM_API_FOR_SH_COMMAND
 #define SET_CONSOLE_CURSOR_SHAPE_METHOD   CURSOR_SHAPE_NOT_SUPPORTED
 
+
+/*-------------------------------------------------------------------*/
+/* Hard-coded FreeBSD-specific features and options...               */
+/*-------------------------------------------------------------------*/
+#elif defined(__FreeBSD__)              /* "FreeBSD" options         */
+
+#define DLL_IMPORT   extern
+#define DLL_EXPORT
+
+#undef  OPTION_SCSI_ERASE_TAPE          /* (NOT supported)           */
+#undef  OPTION_SCSI_ERASE_GAP           /* (NOT supported)           */
+
+#undef  OPTION_TUNTAP_SETMACADDR        /* TUNTAP_SetMACAddr broken  */
+#undef  OPTION_TUNTAP_DELADD_ROUTES     /* Del/Add Routes    broken  */
+
+#define MAX_DEVICE_THREADS          0   /* (0 == unlimited)          */
+#define MIXEDCASE_FILENAMES_ARE_UNIQUE  /* ("Foo" and "fOo" unique)  */
+
+#define DEFAULT_HERCPRIO    0
+#define DEFAULT_TOD_PRIO  -20
+#define DEFAULT_CPU_PRIO   15
+#define DEFAULT_DEV_PRIO    8
+
+#define HOW_TO_IMPLEMENT_SH_COMMAND       USE_ANSI_SYSTEM_API_FOR_SH_COMMAND
+#define SET_CONSOLE_CURSOR_SHAPE_METHOD   CURSOR_SHAPE_NOT_SUPPORTED
+
+
 /*-------------------------------------------------------------------*/
 /* Hard-coded OTHER host-specific features and options...            */
 /*-------------------------------------------------------------------*/
