@@ -3,7 +3,7 @@
 /* may be missing on some platform ports, or other convenient mis-   */
 /* laneous global utility functions.                                 */
 /*********************************************************************/
-/* (c) 2003-2005 Ivan Warren & Others -- Released under the Q Public */
+/* (c) 2003-2006 Ivan Warren & Others -- Released under the Q Public */
 /* License -- This file is portion of the HERCULES S/370, S/390 and  */
 /* z/Architecture emulator                                           */
 /*********************************************************************/
@@ -582,7 +582,7 @@ DLL_EXPORT int timeval_add
   On Windows it converts inpath of the form "/cygdrive/x/foo.bar"
   to outpath in the form "x:/foo.bar" for Windows compatibility.
 */
-DLL_EXPORT BYTE *hostpath( BYTE *outpath, const BYTE *inpath, size_t buffsize )
+DLL_EXPORT char *hostpath( char *outpath, const char *inpath, size_t buffsize )
 {
     if (inpath && outpath && buffsize > 1)
         strlcpy( outpath, inpath, buffsize );
