@@ -406,18 +406,21 @@ static __inline__ int cmpxchg16_i686(U64 *old1, U64 *old2, U64 new1, U64 new2, v
          "movl    %2,%%ebx\n\t"
          "movl    $4,%%ecx\n\t"
          "cld\n\t"
-         "repe    cmpsl\n\t"
+         "repe\n\t"
+         "cmpsl\n\t"
          "jne     1f\n\t"
          "movl    %%ebx,%2\n\t"
          "movl    $4,%%ecx\n\t"
-         "rep     movsl\n\t"
+         "rep\n\t"
+         "movsl\n\t"
          "xorl    %0,%0\n\t"
          "jmp     2f\n"
          "1:\t"
          "movl    %0,%2\n\t"
          "movl    %%ebx,%1\n\t"
          "movl    $4,%%ecx\n\t"
-         "rep     movsl\n\t"
+         "rep\n\t"
+         "movsl\n\t"
          "movl    $1,%0\n"
          "2:"
        : "=q"(code)
@@ -450,18 +453,21 @@ static __inline__ int cmpxchg16_i686(U64 *old1, U64 *old2, U64 new1, U64 new2, v
          "movl    %2,%%ebx\n\t"
          "movl    $4,%%ecx\n\t"
          "cld\n\t"
-         "repe    cmpsl\n\t"
+         "repe\n\t"
+         "cmpsl\n\t"
          "jne     1f\n\t"
          "movl    %%ebx,%2\n\t"
          "movl    $4,%%ecx\n\t"
-         "rep     movsl\n\t"
+         "rep\n\t"
+         "movsl\n\t"
          "xorl    %0,%0\n\t"
          "jmp     2f\n"
          "1:\t"
          "movl    %0,%2\n\t"
          "movl    %%ebx,%1\n\t"
          "movl    $4,%%ecx\n\t"
-         "rep     movsl\n\t"
+         "rep\n\t"
+         "movsl\n\t"
          "movl    $1,%0\n"
          "2:\t"
          "popl    %%ebx"
