@@ -1,8 +1,8 @@
-/* TAPECOPY.C   (c) Copyright Roger Bowler, 1999-2005                */
+/* TAPECOPY.C   (c) Copyright Roger Bowler, 1999-2006                */
 /*              Convert SCSI tape into AWSTAPE format                */
 
 /*              Read from AWSTAPE and write to SCSI tape mods        */
-/*              Copyright 2005 James R. Maynard III                  */
+/*              Copyright 2005-2006 James R. Maynard III             */
 
 /*-------------------------------------------------------------------*/
 /* This program reads a SCSI tape and produces a disk file with      */
@@ -504,7 +504,7 @@ long            density;                /* Tape density code         */
 BYTE            labelrec[81];           /* Standard label (ASCIIZ)   */
 int64_t         bytes_read;             /* Bytes read from i/p file  */
 int64_t         file_bytes;             /* Byte count for curr file  */
-BYTE            pathname[MAX_PATH];     /* file name in host format  */
+char            pathname[MAX_PATH];     /* file name in host format  */
 
 #if defined(ENABLE_NLS)
     setlocale(LC_ALL, "");
