@@ -1,7 +1,7 @@
 //////////////////////////////////////////////////////////////////////////////////////////
 //   w32util.c        Windows porting functions
 //////////////////////////////////////////////////////////////////////////////////////////
-// (c) Copyright "Fish" (David B. Trout), 2005. Released under the Q Public License
+// (c) Copyright "Fish" (David B. Trout), 2005-2006. Released under the Q Public License
 // (http://www.conmicro.cx/hercules/herclic.html) as modifications to Hercules.
 //////////////////////////////////////////////////////////////////////////////////////////
 //
@@ -1220,6 +1220,8 @@ static DWORD WINAPI ReadStdInW32Thread( LPVOID lpParameter )
 
     UNREFERENCED( lpParameter );
 
+    SET_THREAD_NAME ("ReadStdInW32Thread");
+
     for (;;)
     {
         WaitForSingleObject( hGotStdIn, INFINITE );
@@ -1621,6 +1623,7 @@ DLL_EXPORT int w32_FD_ISSET( int fd, fd_set* pSet )
     return 0;   // (file not a member of the specified set)
 }
 //////////////////////////////////////////////////////////////////////////////////////////
+// Win32 "socketpair()" and "pipe()" functionality...
 
 #if !defined( HAVE_SOCKETPAIR )
 
@@ -1637,14 +1640,20 @@ DLL_EXPORT int socketpair( int domain, int type, int protocol, int socket_vector
     // temporary listening socket bound to the localhost loopback address (127.0.0.1)
     // and then having the other socket connect to it...
 
-    if ( AF_INET     != domain   ) return WSAEAFNOSUPPORT;
-    if ( SOCK_STREAM != protocol ) return WSAEPROTONOSUPPORT;
-    if ( IPPROTO_IP  != type     ) return WSAEPROTOTYPE;
+    //  "Upon successful completion, 0 shall be returned; otherwise,
+    //   -1 shall be returned and errno set to indicate the error."
+
+    if ( AF_INET     != domain   ) { errno = WSAEAFNOSUPPORT;    return -1; }
+    if ( SOCK_STREAM != protocol ) { errno = WSAEPROTONOSUPPORT; return -1; }
+    if ( IPPROTO_IP  != type     ) { errno = WSAEPROTOTYPE;      return -1; }
 
     socket_vector[0] = socket_vector[1] = INVALID_SOCKET;
 
     if ( INVALID_SOCKET == (temp_listen_socket = socket( AF_INET, SOCK_STREAM, 0 )) )
-        return (int)WSAGetLastError();
+    {
+        errno = (int)WSAGetLastError();
+        return -1;
+    }
 
     memset( &localhost_addr, 0, len);
 
@@ -1661,7 +1670,8 @@ DLL_EXPORT int socketpair( int domain, int type, int protocol, int socket_vector
     {
         int nLastError = (int)WSAGetLastError();
         closesocket( temp_listen_socket );
-        return nLastError;
+        errno = nLastError;
+        return -1;
     }
 
     if (0
@@ -1673,7 +1683,8 @@ DLL_EXPORT int socketpair( int domain, int type, int protocol, int socket_vector
         closesocket( socket_vector[1] );
                      socket_vector[1] = INVALID_SOCKET;
         closesocket( temp_listen_socket );
-        return nLastError;
+        errno = nLastError;
+        return -1;
     }
 
     closesocket( temp_listen_socket );
@@ -2304,6 +2315,8 @@ DLL_EXPORT pid_t w32_poor_mans_fork ( char* pszCommandLine, int* pnWriteToChildS
     else
         VERIFY(CloseHandle(hWorkerThread));         // (not needed anymore)
 
+    SET_THREAD_NAME_ID(dwThreadId,"w32_read_piped_process_stdOUT_output_thread");
+
     //////////////////////////////////////////////////
     // Stderr...
 
@@ -2334,6 +2347,8 @@ DLL_EXPORT pid_t w32_poor_mans_fork ( char* pszCommandLine, int* pnWriteToChildS
     else
         VERIFY(CloseHandle(hWorkerThread));     // (not needed anymore)
 
+    SET_THREAD_NAME_ID(dwThreadId,"w32_read_piped_process_stdERR_output_thread");
+
     // Return a C run-time file descriptor
     // for the write-to-child-stdin HANDLE...
 
@@ -2481,7 +2496,7 @@ void w32_parse_piped_process_stdxxx_data ( char* holdbuff, int* pnHoldAmount )
     // IMPORTANT PROGRAMMING NOTE! We must use memmove here and not strcpy!
     // strcpy doesn't work correctly for overlapping source and destination.
     // If there's 100 bytes remaining and we just want to slide it left by 1
-    // byte (just as an i" I64_FMT "ustrative example), strcpy screws up. This is more
+    // byte (just as an illustrative example), strcpy screws up. This is more
     // than likely because strcpy is trying to be as efficient as possible and
     // is grabbing multiple bytes at a time from the source string and plonking
     // them down into the destination string, thus wiping out part of our source
@@ -2492,5 +2507,38 @@ void w32_parse_piped_process_stdxxx_data ( char* holdbuff, int* pnHoldAmount )
 }
 
 //////////////////////////////////////////////////////////////////////////////////////////
+// The following is documented in Microsoft's Visual Studio developer documentation...
 
-#endif // defined(WIN32)
+#define  MS_VC_EXCEPTION   0x406D1388       // (special value)
+
+typedef struct tagTHREADNAME_INFO
+{
+    DWORD   dwType;         // must be 0x1000
+    LPCSTR  pszName;        // pointer to name (in same addr space)
+    DWORD   dwThreadID;     // thread ID (-1 caller thread)
+    DWORD   dwFlags;        // reserved for future use, must be zero
+}
+THREADNAME_INFO;
+
+DLL_EXPORT void w32_set_thread_name( TID tid, char* name )
+{
+    THREADNAME_INFO info;
+
+    info.dwType     = 0x1000;
+    info.pszName    = name;         // (should really be LPCTSTR)
+    info.dwThreadID = tid;          // (-1 == current thread, else tid)
+    info.dwFlags    = 0;
+
+    __try
+    {
+        RaiseException( MS_VC_EXCEPTION, 0, sizeof(info) / sizeof(DWORD), (DWORD*)&info );
+    }
+    __except ( EXCEPTION_CONTINUE_EXECUTION )
+    {
+        /* (do nothing) */
+    }
+}
+
+//////////////////////////////////////////////////////////////////////////////////////////
+
+#endif // defined( _MSVC_ )
